==> haskell-mustache-2.3.0-232-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mustache
version: 2.3.0
id: mustache-2.3.0-1mgYIFBC723JXdgWt656Uo
key: mustache-2.3.0-1mgYIFBC723JXdgWt656Uo
license: BSD-3-Clause
copyright: (c) 2015,
           2016 Justus Adam
maintainer: dev@justus.science
author: Justus Adam
homepage: https://github.com/JustusAdam/mustache
synopsis: A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.
    .
    Implements the mustache spec version 1.1.3.
    .
    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.
category: Development
abi: 98044646a4cbf354e4a84b4b0a89b845
exposed: True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types
hidden-modules: Text.Mustache.Internal Text.Mustache.Internal.Types
                Paths_mustache
import-dirs: /usr/lib/ghc-8.6.5/site-local/mustache-2.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/mustache-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mustache-2.3.0
hs-libraries: HSmustache-2.3.0-1mgYIFBC723JXdgWt656Uo
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    either-5.0.1.1-EOMINiddEArIdyO4h91vLl filepath-1.4.2.1 mtl-2.2.2
    parsec-3.1.13.0 scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html: /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mustache-2.3.0-233-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mustache
version: 2.3.0
id: mustache-2.3.0-KSGpIK6RrbvK7ThYcEaGtT
key: mustache-2.3.0-KSGpIK6RrbvK7ThYcEaGtT
license: BSD-3-Clause
copyright: (c) 2015,
           2016 Justus Adam
maintainer: dev@justus.science
author: Justus Adam
homepage: https://github.com/JustusAdam/mustache
synopsis: A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.
    .
    Implements the mustache spec version 1.1.3.
    .
    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.
category: Development
abi: c018b7df4d4e379e6ff482821112369b
exposed: True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types
hidden-modules: Text.Mustache.Internal Text.Mustache.Internal.Types
                Paths_mustache
import-dirs: /usr/lib/ghc-8.6.5/site-local/mustache-2.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/mustache-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mustache-2.3.0
hs-libraries: HSmustache-2.3.0-KSGpIK6RrbvK7ThYcEaGtT
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0
    either-5.0.1.1-EOMINiddEArIdyO4h91vLl filepath-1.4.2.1 mtl-2.2.2
    parsec-3.1.13.0 scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html: /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
